#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "hwidth_14":        256,    #896    =ko_kai
cvt_dict = {
    "base":             10,     #0
    "hstem":            8,      #184
    "hstem_curve":      18,     #195    =big curve hstem
#
    "vstem":            169,    #143    =straight vstem
    "vstem_curve":      185,    #156    =curve vstem
    "vstem":            96,     #154 
    "vstem_small":      27,     #135 
    "vstem_tiny":       9,      #102 
    "vstem_thick":      130,    #266 
    "headstem":         258,    #116
    "headstem_plus_hole":   268, #268
    "headstem_small":   11,     #113    =kho
    "headstem_tiny":    148,    #84
    "headdia":          257,    #384
    "headdia_small":    180,    #377    =kho
    "headdia_tiny":     0,      #309
    "headhole":         107,    #152    
    "headneck_kho":     39,     #180    =kho
#
    "hwidth_1":         78,     #938    =tho
    "hwidth_khai":      14,     #690    =kho_khai, cho_ching
    "hwidth_2":         71,     #1001   =kho_kwai
    "hwidth_3":         231,    #918    =do_chada, no_nane
    "hwidth_4":         108,    #772    =to_thong, ro_ruar
    "hwidth_5":         209,    #905    =lo_ling
    "hwidth_6":         58,     #930    =so_sua
    "hwidth_7":         164,    #987    =po_pung, fo_fa
    "hwidth_8":         73,     #956    =po_pan, fo_fun
    "hwidth_9":         141,    #813    =no_nu, sra_aa
    "hwidth_10":        116,    #852    =wo_wan
    "hwidth_11":        245,    #758    =ngo_ngu, sra_aae, mo_ma
    "hwidth_12":        163,    #881    =po_sampao, to_tahan, yo_yak
    "hwidth_13":        173,    #864    =jo_jan, to_santan, bo_baimai, aw_ang
    "hwidth_14":        256,    #896    =ko_kai
#
    "hnext_1":          68,     #479    =next spline of sho_sher
#
    "vheight":          188,    #1120   =normal height 
    "vheight_shoot":    184,    #1147   =overshoot height
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       151,    #1556   =po_pla, fo_fa
    "vheight_o":        220,    #1917   =sra_o, sra_i
    "vheight_lo":       140,    #29 
    "vheight_lu":       176,    #410    =lo_lu
    "vheight_below_do": 176,    #410
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "front_001":        25,     #211    =front spacing of tho
    "front_kai":        76,     #223    =front spacing of ko_kai
    "front_khai":       89,     #367    =front spacing of kho_khai, do_chada, cho_ching
    "front_khuad":      157,    #451    =front spacing of kho_khud
    "front_kwai":       100,    #205    =front spacing of kho_kwai, yo_yak
    "front_tahan":      38,     #340    =front spaceing of to_tahan
    "front_dek":        106,    #213    =front spaceing of do_dek
    "front_thong":      79,     #229    =front spaceing of to_thong
    "front_pung":       228,    #174    =front spaceing of po_pung
    "front_pan":        31,     #330    =front spacing of do_chada, po_pan
    "front_ma":         180,    #377    =front spaceing of mo_ma
    "front_ling":       1,      #184    =front spaceing of lo_ling, aw_ang
}

######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
srp0    26
mirp[rp0,min,rnd,grey] front_kai 14
mirp[min,rnd,grey]  hstem  12
mirp[rp0,rnd,grey]  hwidth_14 25
mirp[min,rnd,grey]  hstem 1
mdrp[min,rnd,grey]  27
srp0   14
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  17
mdrp[min,rnd,grey]  10
iup[x]
svtca[y-axis]
mdap[rnd]  1
ALIGNRP    13
mirp[rp0,rnd,grey]  vheight_shoot    22
mirp[min,rnd,grey]  vstem_curve  5
srp1    5
srp2    13
sloop   10
ip  19 8 18 9 17 10 2 25 15 12
iup[y]
""",

    #kho_khai
    "uni0E02":  """
srp0    51
mirp[rp0,rnd,grey]  front_khai 0
alignrp     45
mirp[min,rnd,grey]  hstem 29
mirp[rp0,rnd,grey]  hwidth_khai 35
mirp[min,rnd,grey]  hstem 33
mdrp[min,rnd,grey]  52
srp0    45
mirp[rp0,rnd,grey]  headhole  39
mirp[min,rnd,grey]  headstem_small 18
srp0    45
mirp[rp0,rnd,grey]  headstem_small 12
mdrp[rp0,rnd,white]  6
mirp[min,rnd,grey]  vstem_curve 24
srp1    1
srp2    33
sloop   4
ip  3 4 27 28
iup[x]
svtca[y-axis]
mdap[rnd]   0
mirp[rnd,grey]  vheight_shoot 21
mirp[rnd,grey]      vheight 34
mirp[min,rnd,grey]  vstem 30
srp0    21
mirp[min,rnd,grey]  vstem_small 9
mdrp[rp0,rnd,grey]  48
mirp[rp0,min,rnd,grey]  headhole 42
mirp[min,rnd,grey]  headstem_small 15
srp1    9
srp2    30
sloop   8
ip  6 24 4 3 26 27 29 1
iup[y]
""",

    #kho_khuad
    "uni0E03": """
srp0    57
mirp[rp0,min,rnd,grey] front_khuad 0
mirp[min,rnd,grey]  hstem   35
mirp[rp0,rnd,grey]  hwidth_khai 41
mirp[min,rnd,grey]  hstem   39
mdrp[rnd,grey]  58
srp0    0
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem   48
mirp[min,rnd,grey]  headstem_plus_hole  54
mdrp[rp0,rnd,white] 6
mirp[min,rnd,grey]  vstem_curve 30
srp1    0
srp2    30
sloop   4
ip  3 4 33 32
srp1    23
srp2    30
sloop   6
ip  26 10 27 9 28 8
iup[x]
svtca[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem   36
mirp[rnd,grey]  vheight 40
mirp[rp0,rnd,grey]  vheight_shoot   26
alignrp     28
mdrp[min,rnd,grey]  8
shp[rp2]    10
mdrp[rp0,rnd,grey]  27
mirp[rp0,min,rnd,grey]  headstem 9
mdrp[rp0,rnd,white] 14
mdrp[min,rnd,grey]  12
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 20
mirp[min,rnd,grey]  headstem 45
srp1    10
srp2    36
sloop   4
ip  4 32 3 33
iup[y]
""",

    #kho_kwai
    "uni0E04": """
SRP0                     51         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]   front_kwai 29    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  28      ;Move Indirect Relative Point
mdrp[rp0,rnd,grey]  32
MIRP[min,rnd,grey]       hstem  8      ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       hwidth_2  38     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  1       ;Move Indirect Relative Point
MDRP[min,rnd,grey]       52         ;Move Direct Relative Point
srp0    32
mdrp[rp0,rnd,grey]  48
mirp[min,rnd,white]  headhole 42
mirp[min,rnd,grey]  headstem_plus_hole 19
mdrp[min,rnd,grey]  14
mdrp[min,rnd,grey]  24
srp0    28
mdrp[rp0,min,rnd,grey]  11
mdrp[min,rnd,grey]  26
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                0          ;Move Direct Absolute Point
ALIGNRP                  28         ;ALIGN to Reference Point
MIRP[rp0,rnd,grey]       vheight_shoot  35     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       vstem_curve  5      ;Move Indirect Relative Point
MDRP[rp0,rnd,grey]       45         ;Move Direct Relative Point
MIRP[min,rnd,grey]       headstem  16    ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       headhole  39    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       headstem  22    ;Move Indirect Relative Point
srp1    5
srp2    28
sloop 6
ip 32 8 11 26 2 38
IUP[y]                              ;Interpolate Untouched Points through the out
""",

    #ngo_ngu
    "uni0E07": """
srp0    32
mdrp[rp0,min,rnd,grey] 4
mdrp[rnd,grey] 5
mirp[rp0,rnd,grey]  hwidth_11 19
mirp[min,rnd,grey]  hstem 8
shp[rp2]    23
mdrp[min,rnd,grey]  1
mdrp[rnd,grey]  33
srp0 23
mirp[min,rnd,white] headhole 29
mirp[min,rnd,grey]  headstem_plus_hole 14
srp1 4
srp2 19
sloop 4
ip  6 3 7 2
iup[x]
svtca[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 17
mirp[min,rnd,grey]  headstem 26
mirp[rp0,rnd,grey]  headdia 11
mirp[min,rnd,grey]  headstem 20
srp1    11
srp2    1
sloop   3
ip      5 4 8
iup[y]
""",

    #jo_jan
    "uni0E08": """
srp0    44
mdrp[rp0,min,rnd,grey] 22
mirp[rp0,rnd,grey]  hwidth_13 29
mirp[min,rnd,grey]  hstem 16
mdrp[min,rnd,grey]  13
mdrp[min,rnd,grey]  45
srp0 13
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 0
srp0 13
mdrp[min,rnd,grey]  2
mdrp[rp0,rnd,grey] 35
mdrp[min,rnd,grey]  12
mirp[rp0,rnd,white]  headhole 41
mirp[min,rnd,grey]  headstem 7
iup[x]
svtca[y-axis]
mdap[rnd]  1
mdrp[min,rnd,grey]  13
mirp[rp0,rnd,grey]  vheight_shoot 26
mirp[min,rnd,grey]  vstem_curve 19
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 32
srp1    19
srp2    1
sloop   2
ip  16 29
iup[y]
""",

    #cho_ching
    "uni0E09": """
srp0    68
mirp[rp0,min,rnd,grey] front_khai 1
alignrp     47
mirp[min,rnd,grey]  hstem 12
SHP[rp2]    0
mirp[rp0,rnd,grey]  hwidth_khai 29
mirp[min,rnd,grey]  hstem 15
mdrp[min,rnd,grey]  69
srp0    47
mirp[rp0,rnd,grey]  headstem_plus_hole 7
mirp[min,rnd,grey]  headstem 53
srp0    1
mdrp[rp0,rnd,grey]  40
mirp[min,rnd,grey]  headstem 65
mirp[rp0,rnd,grey]  headdia 34
mirp[min,rnd,grey]  headstem 59
srp0    1
mdrp[rnd,grey]  22
iup[x]
svtca[y-axis]
mdap[rnd]   1
mdrp[min,rnd,grey]  13
mirp[rnd,grey]  vheight_lo  37
mirp[rp0,rnd,grey]  vheight_shoot  26
mirp[min,rnd,grey]  vstem_curve 19
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 50
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 44
srp0    37
mdrp[rnd,grey]  42
mirp[rp0,min,rnd,grey]  headstem 56
mirp[rp0,min,rnd,white] headhole    62
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  30
srp1    19
srp2    15
sloop   3
ip  12 16 29
iup[y]
""",

    #cho_chang
    "uni0E0A": """
srp0    60
mirp[rp0,rnd,grey]  front_khai 0
alignrp     51
mirp[min,rnd,grey]  hstem 29
mirp[rp0,rnd,grey]  hwidth_khai 44
mirp[min,rnd,grey]  hstem 33
mdrp[min,rnd,grey]  61
srp0    51
mirp[rp0,rnd,grey]  headhole  57
mirp[min,rnd,grey]  headstem  18
srp0    51
mirp[rp0,rnd,grey]  headstem_small 12
mdrp[rp0,rnd,white]  6
mirp[min,rnd,grey]  vstem_curve 24
srp1    1
srp2    33
sloop   4
ip  3 4 27 24
srp0    44
mdrp[rp0,rnd,grey]  36
mdrp[min,rnd,grey]  42
mdrp[rp0,rnd,grey]  40
mirp[min,rnd,grey]  hstem 39
iup[x]
svtca[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 30
mdrp[rnd,grey]      40
mirp[rp0,rnd,grey]      vheight_shoot 21
mirp[min,rnd,grey]      vstem_small 9
mdrp[rp0,rnd,grey]      54
mirp[rp0,min,rnd,white] headhole 48
mirp[min,rnd,grey]      headstem_small 15
srp1    9
srp2    30
sloop   8
ip  6 24 4 3 26 27 29 1
srp1    40
srp2    30
sloop   5
ip  37 42 36 34 44
iup[y]
""",

    #so_zo
    "uni0E0B": """
srp0    66
mirp[rp0,min,rnd,grey] front_khuad 0
mirp[min,rnd,grey]  hstem   35
mirp[rp0,rnd,grey]  hwidth_khai 50
mirp[min,rnd,grey]  hstem   39
mdrp[rnd,grey]  67
srp0    0
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem   57
mirp[min,rnd,grey]  headstem_plus_hole  63
mdrp[rp0,rnd,white] 6
mirp[min,rnd,grey]  vstem_curve 30
srp1    0
srp2    30
sloop   4
ip  3 4 33 32
srp1    23
srp2    30
sloop   6
ip  26 10 27 9 28 8
srp0    50
mdrp[rp0,rnd,grey]  42
mdrp[min,rnd,grey]  48
mdrp[rp0,rnd,grey]  46
mirp[min,rnd,grey]  hstem 45
iup[x]
svtca[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem   36
mdrp[rnd,grey]  46
mirp[rp0,rnd,grey]  vheight_shoot   26
alignrp     28
mdrp[min,rnd,grey]  10
shp[rp2]    8
mdrp[rp0,rnd,grey]  27
mirp[rp0,min,rnd,grey]  headstem 9
mdrp[rp0,rnd,white] 14
mdrp[min,rnd,grey]  12
mirp[min,rnd,grey]  headstem 60
mirp[rp0,rnd,grey]  headdia 20
mirp[min,rnd,grey]  headstem 54
srp1    10
srp2    36
sloop   4
ip  4 32 3 33
srp1    46
srp2    0
sloop   5
ip  43 48 42 40 50

iup[y]
""",

    #sho_sher
    "uni0E0C": """
srp0    77
mirp[rp0,min,rnd,grey] front_001 36
mirp[min,rnd,grey]  hstem 25
mirp[rp0,rnd,grey]  hwidth_1 47
mirp[min,rnd,grey]  hstem 14
mirp[rp0,rnd,grey]  hnext_1 52
mirp[min,rnd,grey]  hstem 50
shp[rp2]    1
mdrp[min,rnd,grey]  78
srp1    25
srp2    14
sloop   2
ip      31 11
srp0    31
mirp[rp0,rnd,grey]  headstem 56
mirp[rnd,white] headhole 62
srp0    11
mirp[min,rnd,grey]  headstem 74
mirp[rp0,rnd,white] headdia 5
mirp[min,rnd,grey]  headstem 68
srp0    36
mdrp[rp0,rnd,grey]  40
mdrp[min,rnd,grey]  21
mdrp[rp0,rnd,grey]  39
mdrp[min,rnd,grey]  23
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo  8
shp[rp2]    34
mirp[rnd,grey]  vheight 52
mirp[min,rnd,grey]  vstem_curve 50
mirp[rp0,rnd,grey]  vheight_shoot 44
mirp[min,rnd,grey]  vstem 18
srp0    1
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  49
srp0    8
mirp[min,rnd,grey] headstem 65
shp[rp2] 53
mirp[rp0,rnd,grey] headdia 14
alignrp 28
mirp[min,rnd,grey]  headstem 71
shp[rp2] 59
srp1    18
srp2    8
sloop   10
ip  41 21 40 22 39 23 15 47 37 25
iup[y]
""",

    #yo_ying
    "uni0E0D": """
srp0    82
mirp[rp0,min,rnd,grey] front_001 23
mirp[min,rnd,grey]  hstem 12
shp[rp2]    48
mirp[rp0,rnd,grey]  hwidth_1 34
mirp[min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  hnext_1  38
alignrp     67
mirp[min,rnd,grey]  hstem 36
mdrp[min,rnd,grey]  83
srp0    23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  49
#srp0    48
#mirp[rp0,min,rnd,grey] headstem_plus_hole 18
srp0    23
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  18
#
mirp[min,rnd,grey]  headstem 42
srp0    67
mdrp[rp0,rnd,grey]  54
mirp[min,rnd,grey]  headstem_tiny 79
mirp[rp0,rnd,white] headdia_small 60
mirp[min,rnd,grey]  headstem_tiny 73
mdrp[rnd,grey]  62
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[rnd,grey]  vheight 38
mirp[min,rnd,grey]  vstem 35
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey] headstem 39
mirp[rp0,rnd,grey] headdia 15
mirp[min,rnd,grey]  headstem 45
srp0    1
mdrp[rp0,rnd,grey] 57
mirp[min,rnd,grey]  headstem_tiny 76
mdrp[rp0,min,rnd,grey]  51
mdrp[rnd,grey]  67
mdrp[rp0,min,rnd,grey]  62
mdrp[min,rnd,grey]  70
mdrp[rnd,grey]  66
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
iup[y]
""",

    #do_chada
    "uni0E0E": """
srp0    74
mirp[rp0,min,rnd,grey]  front_khai 40
alignrp 55
mirp[min,rnd,grey]  hstem 29
mirp[rp0,rnd,grey]  hwidth_12 51
mirp[min,rnd,grey]  hstem   18
shp[rp2]    1
mdrp[min,rnd,grey]  75
srp0    40
mdrp[rp0,rnd,grey]  44
mdrp[min,rnd,grey]  25
mdrp[rp0,rnd,grey]  43
mdrp[min,rnd,grey]  27
srp0    55
mirp[rp0,rnd,grey]  headstem_plus_hole 35
mirp[min,rnd,grey]  headstem 61
srp0    40
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  vstem_curve 71
srp1    71
srp2    18
sloop   6
ip  66 13 14 3 16 15
iup[x]
svtca[y-axis]
mdap[rnd]   74
mirp[rnd,grey]  vheight_lo 32
mirp[rnd,grey]  vheight_lu 1
shp[rp2]    5
mirp[rp0,rnd,grey]  vheight_shoot 48
mirp[min,rnd,grey]  vstem_curve   22
srp0    32
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headdia 38
mirp[min,rnd,grey]  headstem 58
srp0    5
mirp[min,rnd,grey]  vstem   64
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  vstem   68
srp1    11
srp2    5
sloop   7
ip  14 15 13 16 66 3 18
srp1    22
srp2    32
sloop   10
ip  45 25 44 26 43 27 19 51 41 29
iup[y]
""",

    #to_patak
    "uni0E0F": """
srp0    78
mirp[rp0,min,rnd,grey]  front_khai 46
alignrp 61
mirp[min,rnd,grey]  hstem 35
mirp[rp0,rnd,grey]  hwidth_12 57
mirp[min,rnd,grey]  hstem   24
shp[rp2]    1
mdrp[min,rnd,grey]  79
srp0    38
mdrp[rp0,rnd,grey]  50
mdrp[min,rnd,grey]  31
mdrp[rp0,rnd,grey]  49
mdrp[min,rnd,grey]  33
srp0    61
mirp[rp0,rnd,grey]  headstem_plus_hole 41
mirp[min,rnd,grey]  headstem 67
srp0    38
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem 76
srp1    76
srp2    24
sloop   12
ip  72 16 17 6 19 18 4 21 3 22 2 23
iup[x]
svtca[y-axis]
mdap[rnd]   78
mirp[rnd,grey]  vheight_lo 38
mirp[rnd,grey]  vheight_lu 8
mirp[rp0,rnd,grey]  vheight_shoot 54
mirp[min,rnd,grey]  vstem_curve   28
srp0    38
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 44
mirp[min,rnd,grey]  headstem 64
srp0   8
alignrp 4
alignrp 1 
mirp[min,rnd,grey]  headstem   70
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem   74
srp1    28
srp2    38
sloop   10
ip  51 31 50 32 49 33 25 57 47 35
srp1    14
srp2    8
sloop   9
ip  17 16 19 22 72 6 21 24 2
iup[y]
""",

    #to_santan
    "uni0E10": """
srp0    117
mdrp[rp0,min,rnd,grey]  19
mirp[rp0,rnd,grey]  hwidth_13   44
mirp[min,rnd,grey]  hstem   16
mdrp[rnd,grey]  118
srp0    19
mdrp[min,rnd,grey]  41
mdrp[rnd,grey]  31
srp0    16
mdrp[rp0,rnd,grey]  50
mdrp[min,rnd,grey]  12
mirp[rp0,rnd,grey]  headstem_plus_hole  7
mirp[min,rnd,grey]      headstem    56
srp0    16
mdrp[rp0,rnd,grey]  13
mdrp[rp0,min,rnd,grey]  1
mirp[min,rnd,grey]  hstem   0
mdrp[rp0,rnd,grey]  94
mdrp[min,rnd,grey]  59
mdrp[min,rnd,grey]  91
mdrp[rp0,min,rnd,grey]  70
mdrp[min,rnd,grey]  115
srp0    59
mdrp[min,rnd,grey]  85
mdrp[min,rnd,grey]  100
srp0    91
mdrp[min,rnd,grey]  106
srp1    115
srp2    85
sloop   11
ip  111 75 65 80 63 82 62 83 61 84 60
iup[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
mdap[rnd]   1
mdrp[min,rnd,grey]  13
mirp[rp0,rnd,grey]  vheight_shoot   23
mirp[min,rnd,grey]  vstem_curve 38
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  vstem 31
srp0    38
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem    53
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 47
srp1    38
srp2    10
sloop   7
ip  20 41 19 42 18 16 44
srp0    1
mdrp[rp0,rnd,grey]  94
mdrp[min,rnd,grey]  103
mdrp[rp0,rnd,grey]  88
mdrp[min,rnd,grey]  97
mdrp[rp0,rnd,grey]  59
alignrp 62
alignrp 67
srp0    67
mdrp[min,rnd,grey]  109
mdrp[rp0,rnd,grey]  73
mdrp[min,rnd,grey]  113
srp1    73
srp2    67
sloop   9
ip  77 75 78 111 80 65 83 61 85
iup[y]
""",

    #to_nangmonto
    "uni0E11": """
srp0    66
mirp[rp0,min,rnd,grey]  front_khuad 10
mirp[min,rnd,grey]  hstem   46
shp[rp2]    9
mirp[rp0,rnd,grey]  hwidth_12 53
mirp[min,rnd,grey]  hstem   1
mdrp[rnd,grey]  67
srp0    10
mdrp[rp0,rnd,grey]  33
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  headstem    57
mirp[rnd,grey]  headstem_plus_hole  63
mdrp[rp0,min,rnd,white] 16
mdrp[rp0,rnd,grey]  40
srp1    40
srp2    2
sloop   4
ip  48 49 7 6
srp1    22
srp2    16
sloop   6
ip  36 20 37 19 38 18
iup[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
mdap[rnd]   10
alignrp 1
mdrp[min,rnd,grey]  46
mirp[rp0,rnd,grey]  vheight_shoot   51
alignrp 36
alignrp 38
mirp[min,rnd,grey]  vstem_curve 4
srp0    36
mdrp[min,rnd,grey]  20
shp[rp2]    18
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  24
mirp[min,rnd,grey]  headstem    60
mirp[rp0,rnd,grey]  headdia 30
mirp[min,rnd,grey]  headstem 54
srp1    51
srp2    46
sloop   12
ip  49 48 6 7 2 53 14 13 42 43 45 11
iup[y]
""",

    #to_putao
    "uni0E12": """
SRP0                    82         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]  front_dek 41    ;Move Indirect Relative Point
MIRP[min,rnd,grey]      hstem  40      ;Move Indirect Relative Point
mdrp[min,rnd,grey]      25
MDRP[rp0,rnd,grey]      44         ;Move Direct Relative Point
MIRP[min,rnd,grey]      hstem  22    ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]      hwidth_2  52     ;Move Indirect Relative Point
MIRP[min,rnd,grey]      hstem  14      ;Move Indirect Relative Point
mirp[rp0,rnd,grey]      hnext_1 57
MIRP[min,rnd,grey]      hstem  55      ;Move Indirect Relative Point
shp[rp2]                1
MDRP[min,rnd,grey]      83         ;Move Direct Relative Point
srp0    22
mdrp[rp0,rnd,grey]      36
mdrp[min,rnd,grey]      27
mirp[min,rnd,grey]      headstem 61
mirp[rp0,rnd,grey]      headdia 30
mirp[min,rnd,grey]      headstem 67
srp1    22
srp2    15
sloop   7
ip  47 20 48 19 18 49 17
srp0    14
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  headstem 73
mirp[rp0,rnd,grey]  headdia 11
mirp[min,rnd,grey]  headstem 79
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]               1          ;Move Direct Absolute Point
ALIGNRP                 40         ;ALIGN to Reference Point
mirp[min,rnd,grey]      vstem_curve 55
shp[rp2]                25
mirp[rnd,grey]          vheight_lo  8
mirp[rnd,grey]          vheight 57
MIRP[rp0,rnd,grey]      vheight_shoot  49     ;Move Indirect Relative Point
alignrp 47
MIRP[min,rnd,grey]      vstem_curve  17     ;Move Indirect Relative Point
shp[rp2]    20
mdrp[rp0,rnd,grey]  48
mirp[rp0,min,rnd,grey]  headstem 18
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 33
mirp[min,rnd,grey]  headstem 64
srp0    8
mirp[min,rnd,grey]  headstem 70
mirp[rp0,rnd,grey]  headdia 14
mirp[min,rnd,grey]  headstem 76
mdrp[rp0,rnd,grey]  53
mdrp[min,rnd,grey]  3
srp1    18
srp2    25
sloop   4
ip  42 22 15 52
IUP[y]                              ;Interpolate Untouched Points
""",

    #no_nane
    "uni0E13": """
srp0    77
mirp[rp0,min,rnd,grey] front_001 23
mirp[min,rnd,grey]  hstem 12
shp[rp2]    62
mirp[rp0,rnd,grey]  hwidth_3 34
alignrp 0
mirp[min,rnd,grey]  hstem 1
mirp[rp0,rnd,grey]  hnext_1 39
mirp[min,rnd,grey]  hstem 37
mdrp[min,rnd,grey]  78
srp0    23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
srp0    62
mirp[rp0,rnd,white] headhole 56
mirp[min,rnd,grey]  headstem 18
srp0    0
mdrp[rp0,rnd,grey] 49
mirp[min,rnd,grey]  headstem 74
mirp[rp0,rnd,grey]  headdia 43
mirp[min,rnd,grey]  headstem 68
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
shp[rp2]    46
mirp[rnd,grey]  vheight 39
mirp[min,rnd,grey]  vstem_curve 35
mdrp[rnd,grey]  51
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey] headstem 53
shp[rp2]    65
mirp[rp0,rnd,grey] headdia 15
mirp[min,rnd,grey]  headstem 59
shp[rp2]    71
srp0    71
mdrp[min,rnd,grey] 37
mdrp[min,rnd,grey] 40
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
iup[y]
""",

    #do_dek
    "uni0E14": """
SRP0                     49         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]   front_dek 27    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  26      ;Move Indirect Relative Point
mdrp[min,rnd,grey]       11
MDRP[rp0,rnd,grey]       30         ;Move Direct Relative Point
MIRP[min,rnd,grey]       hstem  8       ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       hwidth_2  36     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  1       ;Move Indirect Relative Point
MDRP[min,rnd,grey]       50         ;Move Direct Relative Point
srp0    8
mdrp[rp0,rnd,grey]  22
mdrp[min,rnd,grey]  13
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 16
mirp[min,rnd,grey]  headstem 46
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                1          ;Move Direct Absolute Point
ALIGNRP                  26         ;ALIGN to Reference Point
MIRP[rp0,rnd,grey]       vheight_shoot  33     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       vstem_curve  5      ;Move Indirect Relative Point
mdrp[rp0,rnd,grey]      13
mirp[min,rnd,grey]      headstem 37
mirp[rp0,rnd,grey]      headdia 19
mirp[min,rnd,grey]      headstem 43
srp0                    26
mirp[min,rnd,grey]      vstem_curve 11
srp1                    5
srp2                    11
sloop                   4
ip                      30 8 2 36
IUP[y]                              ;Interpolate Untouched Points 
""",

    #to_tao
    "uni0E15": """
SRP0                     52         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]   front_dek 28    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  27      ;Move Indirect Relative Point
mdrp[min,rnd,grey]       12
MDRP[rp0,rnd,grey]       31         ;Move Direct Relative Point
MIRP[min,rnd,grey]       hstem  9     ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       hwidth_2  39     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  1       ;Move Indirect Relative Point
MDRP[min,rnd,grey]       53         ;Move Direct Relative Point
srp0    9
mdrp[rp0,rnd,grey]      23
mdrp[min,rnd,grey]      14
mirp[min,rnd,grey]      headstem 43
mirp[rp0,rnd,grey]      headdia 17
mirp[min,rnd,grey]      headstem 49
srp1    9
srp2    2
sloop   7
ip  34 7 35 6 5 36 4
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]               1          ;Move Direct Absolute Point
ALIGNRP                 27         ;ALIGN to Reference Point
MIRP[rp0,rnd,grey]      vheight_shoot  36     ;Move Indirect Relative Point
alignrp 34
MIRP[min,rnd,grey]      vstem_curve  4      ;Move Indirect Relative Point
shp[rp2]    7
mdrp[rp0,rnd,grey]  35
mirp[rp0,min,rnd,grey]  headstem 5
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 20
mirp[min,rnd,grey]  headstem 46
srp0    27
mirp[min,rnd,grey]  vstem_curve 12
srp1    5
srp2    12
sloop   4
ip  31 9 2 39
IUP[y]                              ;Interpolate Untouched Points 
""",

    #to_tung
    "uni0E16": """
srp0    47
mirp[rp0,min,rnd,grey] front_001 23
mirp[min,rnd,grey]  hstem 12
shp[rp2]    44
mirp[rp0,rnd,grey]  hwidth_1 34
mirp[min,rnd,grey]  hstem 1
mdrp[min,rnd,grey]  48
srp0   23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
srp0   44
mirp[rp0,min,rnd,white] headhole 38
mirp[min,rnd,grey]  headstem 18 
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem 5
srp0    21
mirp[min,rnd,grey]  headstem    35
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem    41
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
iup[y]
""",

    #to_tahan
    "uni0E17": """
srp0    40
mirp[rp0,min,rnd,grey] front_tahan 9
alignrp 31
mirp[min,rnd,grey]  hstem 21
shp[rp2]    8
mirp[rp0,rnd,grey]  hwidth_12 27
mirp[min,rnd,grey]  hstem 1
mdrp[min,rnd,grey]  41
srp0   31
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  headstem 37
srp1   21
srp2   1
sloop   4
ip  23 6 4 25
iup[x]
svtca[y-axis]
mdap[rnd]  1
alignrp 8
mirp[rp0,rnd,grey]  vheight_shoot 25
alignrp 18
mirp[min,rnd,grey]  vstem_curve 4
srp0    18
mirp[min,rnd,grey]  headstem 34
mirp[rp0,rnd,grey]  headdia 12
mirp[min,rnd,grey]  headstem 28
srp0    8
mdrp[min,rnd,grey]  21
srp1    25
srp2    21
sloop   5
ip  20 23 6 4 27
iup[y]
""",

    #to_thong
    "uni0E18": """
srp0    39
mirp[rp0,min,rnd,grey] front_thong 0
mirp[min,rnd,grey]  hstem 3
mirp[rp0,rnd,grey]  hwidth_4 35
mirp[min,rnd,grey]  hstem 6
mdrp[min,rnd,grey]  40
srp0   0
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  32
mdrp[rnd,grey]  22
iup[x]
svtca[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 3
mirp[rp0,rnd,grey]  vheight_shoot 14
mirp[min,rnd,grey]  vstem_curve 29
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  vstem 21
srp1    29
srp2    3
sloop   8
ip  11 32 10 33 9 2 35 7
iup[y]
""",

    #no_nu
    "uni0E19": """
srp0    55
mirp[rp0,min,rnd,grey] front_tahan 1
alignrp 34
mirp[min,rnd,grey]  hstem 13
shp[rp2]    0
mirp[rp0,rnd,grey]  hwidth_9 17
mirp[min,rnd,grey]  hstem 15
mdrp[min,rnd,grey]  56
srp0   34
mirp[rp0,rnd,grey]  headstem_plus_hole 7
mirp[min,rnd,grey]  headstem 40
srp0    18
mdrp[rp0,rnd,grey]  29
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 46
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 24
mirp[rnd,grey]  vheight 17
mdrp[min,rnd,grey]  13
mirp[rp0,min,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 37
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 31
srp0    24
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headstem_plus_hole 49
mdrp[min,rnd,grey]  18
mdrp[min,rnd,grey]  15
mdrp[min,rnd,grey]  29
iup[y]
""",

    #bo_baimai
    "uni0E1A": """
srp0    29
mirp[rp0,min,rnd,grey] front_tahan 1
alignrp 20
mirp[min,rnd,grey]  hstem 13
mirp[rp0,rnd,grey]  hwidth_13 16
mirp[min,rnd,grey]  hstem 14
mdrp[min,rnd,grey]  30
srp0   20
mirp[rp0,rnd,grey]  headstem_plus_hole 7
mirp[min,rnd,white] headstem 26
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight 16
mirp[min,rnd,grey]  vstem 13
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 23
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 17
iup[y]
""",

    #po_pla
    "uni0E1B": """
srp0    29
mirp[rp0,min,rnd,grey] front_tahan 1
alignrp 20
mirp[min,rnd,grey]  hstem 13
mirp[rp0,rnd,grey]  hwidth_13 16
mirp[min,rnd,grey]  hstem 14
mdrp[min,rnd,grey]  30
srp0   20
mirp[rp0,rnd,grey]  headstem_plus_hole 7
mirp[min,rnd,white] headstem 26
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_po 16
mirp[min,rnd,grey]  vstem 13
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 23
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 17
iup[y]
""",

    #po_pung
    "uni0E1C": """
srp0    34
mirp[rp0,min,rnd,grey]  front_pung 4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    31
mirp[rp0,rnd,grey]  hwidth_7 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  35
srp0    31
alignrp 3
mirp[rp0,rnd,grey]  headstem_plus_hole 10
mirp[min,rnd,grey]  headstem 25
srp1    15
srp2    19
sloop 3
ip  17 2 18
iup[x]
svtca[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 22
mdrp[rp0,rnd,white] 17
mirp[min,rnd,grey]  vstem 2
iup[y]
""",

    #fo_fa
    "uni0E1D": """
srp0    34
mirp[rp0,min,rnd,grey]  front_pung 4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    31
mirp[rp0,rnd,grey]  hwidth_7 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  35
srp0    31
alignrp 3
mirp[rp0,rnd,grey]  headstem_plus_hole 10
mirp[min,rnd,grey]  headstem 25
srp1    15
srp2    19
sloop 3
ip  17 2 18
iup[x]
svtca[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 22
mdrp[rp0,rnd,white] 17
mirp[min,rnd,grey]  vstem 2
iup[y]
""",

    #po_pan
    "uni0E1E": """
srp0    34
mirp[rp0,min,rnd,grey]  front_pan 4
shp[rp2]    25
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mirp[rp0,rnd,grey]  hwidth_1 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  35
srp0    25
mirp[rp0,rnd,grey]  headstem_plus_hole 10
mirp[min,rnd,grey]  headstem 31
srp1    15
srp2    19
sloop   3
ip      17 2 18 
iup[x]
svtca[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[min,rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 22
srp1    13
srp2    19
sloop   2
ip  17 2
iup[y]
""",

    #fo_fun
    "uni0E1F": """
srp0    34
mirp[rp0,min,rnd,grey]  front_pan 4
shp[rp2]    25
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mirp[rp0,rnd,grey]  hwidth_1 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  35
srp0    25
mirp[rp0,rnd,grey]  headstem_plus_hole 10
mirp[min,rnd,grey]  headstem 31
srp1    15
srp2    19
sloop   3
ip      17 2 18 
iup[x]
svtca[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[min,rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 28
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 22
srp1    13
srp2    19
sloop   2
ip  17 2
iup[y]
""",

    #po_sampao
    "uni0E20": """
srp0    47
mirp[rp0,min,rnd,grey]  front_khai 23
alignrp 38
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  hwidth_12 34
mirp[min,rnd,grey]  hstem   1
mdrp[min,rnd,grey]  48
srp0    23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
srp0    38
mirp[rp0,rnd,grey]  headstem_plus_hole 18
mirp[min,rnd,white] headstem 44
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve   5
srp0    15
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 41
srp1    5
srp2    1
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
iup[y]
""",

    #mo_ma
    "uni0E21": """
srp0    55
mirp[rp0,min,rnd,grey]  front_ma 14
alignrp 34 
mirp[min,rnd,grey]  hstem 25
shp[rp2]    3
mirp[rp0,rnd,grey]  hwidth_11 30
mirp[min,rnd,grey]  hstem   28
shp[rp2]    1
mdrp[min,rnd,grey]  56
srp0    34
alignrp 46 
mirp[rp0,rnd,grey]  headstem_plus_hole 20
mirp[min,rnd,grey]  headstem 40
srp0    46
mirp[rp0,rnd,grey]  headstem_plus_hole 9
mirp[min,rnd,grey]  headstem 52
iup[x]
svtca[y-axis]
mdap[rnd]   1
mirp[rnd,grey]  vheight_lo 6
mirp[rnd,grey]  vheight 30
mirp[rp0,rnd,grey]  vheight_shoot 23
mirp[min,rnd,grey]  headstem 37
mirp[rp0,rnd,grey]  headdia 17
mirp[min,rnd,grey]  headstem 31
srp0    6
mdrp[min,rnd,grey]  43
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  3
iup[y]
""",

    #yo_yak
    "uni0E22": """
srp0    44
mirp[rp0,min,rnd,grey]  front_kwai 1
mirp[min,rnd,grey]  hstem 27
shp[rp2]    41
mirp[rp0,rnd,grey]  hwidth_12 31
mirp[min,rnd,grey]  hstem  29
mdrp[min,rnd,grey]  45
#srp0    1
#mdrp[rp0,rnd,grey]  7
#mdrp[min,rnd,grey]  21
#mdrp[rp0,rnd,grey]  19
#mdrp[min,rnd,grey]  41
#mdrp[rp0,rnd,grey]  13
#mirp[min,rnd,grey]  headstem 35
srp0    41
mirp[rp0,min,rnd,grey] headstem 19
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  7
srp0    41
mirp[rp0,rnd,grey]  headstem_plus_hole 13
mirp[min,rnd,grey]  headstem 35
#
srp0    21
mdrp[rp0,rnd,white] 24
mdrp[min,rnd,grey]  4
iup[x]
svtca[y-axis]
mdap[rnd] 1
mirp[rnd,grey]      vheight 31
mirp[min,rnd,grey]  vstem 28
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 16
mirp[min,rnd,grey]  headstem 32
srp1    16
srp2    28
sloop   7
ip  7 19 24 4 25 2 27
iup[y]
""",

    #ro_ruar
    "uni0E23": """
srp0    52
mdrp[rp0,min,rnd,grey]  12
mirp[rp0,rnd,grey]  hwidth_4    37
mirp[min,rnd,grey]  hstem 8
shp[rp2]    43
mdrp[rnd,grey]  53
srp0    43
mirp[rp0,rnd,grey]  headstem_plus_hole  3
mirp[min,rnd,grey]  headstem    49
srp0    12
mirp[min,rnd,grey]  vstem   34
mdrp[rnd,grey]  24
iup[x]
svtca[y-axis]
mdap[rnd]  0
mirp[rp0,rnd,grey]  vheight_shoot 16
mirp[min,rnd,grey]  vstem_curve 31
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  vstem   24
srp0    0
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 6
mirp[min,rnd,grey]  headstem 46
srp1 31
srp2 6
sloop 7
ip 13 34 12 35 11 9 37
iup[y]
""",

    #lo_lu
    "uni0E24": """
srp0    47
mirp[rp0,min,rnd,grey] front_001 23
mirp[min,rnd,grey]  hstem 12
shp[rp2]    44
mirp[rp0,rnd,grey]  hwidth_1 34
mirp[min,rnd,grey]  hstem 1
mdrp[min,rnd,grey]  48
srp0   23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
srp0   44
mirp[rp0,min,rnd,white] headhole 38
mirp[min,rnd,grey]  headstem 18
iup[x]
svtca[y-axis]
mdap[rnd]  47
mirp[rnd,grey]  vheight_lo 21
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve 5
srp0    21
mirp[min,rnd,grey]  headstem    35
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem    41
srp1    5
srp2    21
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
iup[y]
""",

    #lo_ling
    "uni0E25": """
srp0    51
mirp[rp0,min,rnd,grey] front_ling 17
alignrp 31
mirp[min,rnd,grey]  hstem 6
shp[rp2]    48
mirp[rp0,rnd,grey]  hwidth_5 38
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
mdrp[min,rnd,grey]  52
srp0    48
mirp[rp0,rnd,grey]  headstem_plus_hole 12
mirp[min,rnd,grey]  headstem    42
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mdrp[min,rnd,grey]  24
mirp[rp0,rnd,grey]  vheight_shoot 35
mirp[min,rnd,grey]  vstem_curve 28
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem_curve   4
srp0    15
mirp[min,rnd,grey]  headstem 39
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 45
srp1    28
srp2    9
sloop   4
ip  18 6 25 38
iup[y]
""",

    #ro_ru
    "uni0E26": """
srp0    47
mirp[rp0,min,rnd,grey]  front_khai 23
alignrp 38
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  hwidth_12 34
mirp[min,rnd,grey]  hstem   1
mdrp[min,rnd,grey]  48
srp0    23
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
srp0    38
mirp[rp0,rnd,grey]  headstem_plus_hole 18
mirp[min,rnd,white] headstem 44
iup[x]
svtca[y-axis]
mdap[rnd]   47
mirp[rnd,grey]  vheight_lo 15
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_curve   5
srp0    15
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 41
srp1    5
srp2    15
sloop   10
ip  28 8 27 9 26 10 2 34 24 12
iup[y]
""",

    #wo_wan
    "uni0E27": """
srp0    37
mdrp[rp0,min,rnd,grey]  15
mirp[rp0,min,rnd,grey]  hwidth_10   22
mirp[min,rnd,grey]  hstem 8
shp[rp2]    28
mdrp[min,rnd,grey]  38
srp0    28
mirp[rp0,rnd,grey]  headstem_plus_hole    3
mirp[min,rnd,grey]  headstem    34
iup[x]
svtca[y-axis]
srp0    37
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 19
mirp[min,rnd,grey]  vstem_curve   12
srp0    0
mirp[min,rnd,grey]  headstem 25
mirp[rp0,rnd,grey]  headdia 6
mirp[min,rnd,grey]  headstem 31
srp1    12
srp2    6
sloop   2
ip  9 22
iup[y]
""",

    #so_sala
    "uni0E28": """
SRP0                     63         ;Set Reference Point 0
MIRP[rp0,min,rnd,grey]   front_kwai 35    ;Move Indirect Relative Point
mirp[min,rnd,grey]       hstem 34
MDRP[rp0,min,rnd,grey]   38    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  14      ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       hwidth_2  50     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       hstem  1       ;Move Indirect Relative Point
MDRP[min,rnd,grey]       64         ;Move Direct Relative Point
srp0    34
mdrp[rp0,min,rnd,grey]  17
mdrp[min,rnd,grey]  32
srp0    14
mdrp[rp0,rnd,grey]  60
mdrp[min,rnd,grey]  22
mdrp[min,rnd,grey]  30
mirp[rp0,rnd,grey]  headstem_plus_hole  25
mirp[min,rnd,grey]  headstem    54
srp1    25
srp2    50
sloop   8 
ip  7 6 9 4 43 48 45 46
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                34         ;Move Direct Absolute Point
ALIGNRP                  1         ;ALIGN to Reference Point
mdrp[min,rnd,grey]  17
MIRP[rp0,rnd,grey]       vheight_shoot  41     ;Move Indirect Relative Point
MIRP[min,rnd,grey]       vstem  11     ;Move Indirect Relative Point
MDRP[rp0,rnd,grey]       22         ;Move Direct Relative Point
MIRP[min,rnd,grey]       headstem  57    ;Move Indirect Relative Point
MIRP[rp0,rnd,grey]       headdia  28    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       headstem  51    ;Move Indirect Relative Point
srp1    41
srp2    22
sloop   8
ip  45 46 43 48 9 7 4 6
srp1    11
srp2    17
sloop 4
ip  38 14 2 50
IUP[y]                              ;Interpolate Untouched Points through the out
""",

    #so_lusi
    "uni0E29": """
srp0    64
mirp[rp0,min,rnd,grey] front_tahan 1
alignrp 43
mirp[min,rnd,grey]  hstem 13
mirp[rp0,rnd,grey]  hwidth_13 33
alignrp 39
mirp[min,rnd,grey]  hstem 31
shp[rp2]    15
mdrp[min,rnd,grey]  65
srp0   43
mirp[rp0,rnd,grey]  headstem_plus_hole  7
mirp[min,rnd,grey]  headstem 49
srp0    31
mdrp[rp0,min,rnd,white] 26
mirp[min,rnd,grey]  headstem_tiny   55
mirp[rp0,rnd,grey]  headdia_tiny    20
mirp[min,rnd,grey]  headstem_tiny   61
srp0    34
mdrp[min,rnd,grey]  36
mdrp[min,rnd,grey]  37
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]      vheight 33
mirp[min,rnd,grey]  vstem   13
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 40
srp0    14
mdrp[rp0,min,rnd,white] 17
mirp[min,rnd,grey]  vstem_tiny 28
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem_tiny   58
mdrp[min,rnd,grey]  52
srp1    23
srp2    17
sloop   6
ip  36 34 37 31 39 15
iup[y]
""",

    #so_sua
    "uni0E2A": """
srp0    63
mirp[rp0,min,rnd,grey]  front_ling 17
alignrp 37
mirp[min,rnd,grey]  hstem 6
shp[rp2]    60
mirp[rp0,rnd,grey]  hwidth_5 50
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
mdrp[min,rnd,grey]  64
srp0    60  
mirp[rp0,rnd,grey]  headstem_plus_hole  12
mirp[min,rnd,grey]  headstem    54
srp1    25
srp2    50
sloop   8
ip  30 29 32 27 43 48 45 46
iup[x]
svtca[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 41
mirp[min,rnd,grey]  vstem 34
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem   4
srp0    15
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 57
srp1    41
srp2    21
sloop   8
ip  45 46 43 48 32 30 27 29
srp1    34
srp2    9
sloop   4
ip  18 6 25 50
iup[y]
""",

    #ho_hib
    "uni0E2B": """
SRP0                    64         ;Set Reference Point 0
mirp[rp0,min,rnd,grey]  front_tahan 9
alignrp     43
MIRP[min,rnd,grey]      hstem  21      ;Move Indirect Relative Point
shp[rp2]    8
MIRP[rp0,rnd,grey]      hwidth_12  39     ;Move Indirect Relative Point
alignrp     34
MIRP[min,rnd,grey]      hstem  1       ;Move Indirect Relative Point
MDRP[min,rnd,grey]      65         ;Move Direct Relative Point
SRP0        43                    ;Set Reference Point 0
mirp[rp0,rnd,grey]      headstem_plus_hole  15
MIRP[min,rnd,grey]      headstem  49    ;Move Indirect Relative Point
srp0        34
mirp[min,rnd,grey]  headstem    55
mirp[rp0,rnd,grey]  headdia     28
mirp[min,rnd,grey]  headstem    61
srp1    28
srp2    34
sloop   3
ip      25 4 37
IUP[x]                              ;Interpolate Untouched Points through the outline
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]                8          ;Move Direct Absolute Point
ALIGNRP                  1          ;ALIGN to Reference Point
mdrp[min,rnd,grey]      21
MIRP[rp0,rnd,grey]      vheight_shoot  18     ;Move Indirect Relative Point
alignrp     31
MIRP[min,rnd,grey]       headstem  46     ;Move Indirect Relative Point
shp[rp2]    58
MIRP[rp0,rnd,grey]       headdia  12    ;Move Indirect Relative Point
MIRP[min,rnd,grey]       headstem  40    ;Move Indirect Relative Point
shp[rp2]    52
srp1                    31
srp2                    8
sloop                   7
ip  25 37 4 23 6 2 39
IUP[y]                              ;Interpolate Untouched Points 
""",

    #lo_jula
    "uni0E2C": """
srp0    61
mirp[rp0,min,rnd,grey]  front_pan 4
alignrp 40
mirp[min,rnd,grey]  hstem 16
shp[rp2]    3
mirp[rp0,rnd,grey]  hwidth_7 36
alignrp 30
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
mdrp[min,rnd,grey]  62
srp0    40
mirp[rp0,rnd,grey]  headstem_plus_hole 10
mirp[min,rnd,white] headstem 46
srp0    30
mirp[min,rnd,grey]  headstem    52
mirp[rp0,rnd,grey]  headdia    24
mirp[min,rnd,grey]  headstem    58
srp1    16
srp2    19
sloop 3
ip  17 2 18
srp1 36
srp2 62
sloop 2
ip 33 34
iup[x]
svtca[y-axis]
srp0    1
alignrp    3
mdrp[min,rnd,grey]  19
shp[rp2]   16
mdrp[rnd,grey]  27
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 37
srp0    27
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 21
mirp[min,rnd,grey]  headstem 49
srp1    13
srp2    19
sloop   2
ip  17 2
srp1    27
srp2    23
sloop   4
ip  31 33 34 36
iup[y]
""",

    #aw_ang
    "uni0E2D": """
srp0    41
mirp[rp0,min,rnd,grey]  front_ling 1
alignrp 21
mirp[min,rnd,grey]  hstem   12
shp[rp2]    38
mirp[rp0,rnd,grey]  hwidth_13   28
mirp[min,rnd,grey]  hstem   14
mdrp[rnd,grey]      42
srp0    38
mirp[rp0,rnd,grey]  headstem_plus_hole  7
mirp[min,rnd,grey]  headstem    32
iup[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   14
mirp[rp0,rnd,grey]  vheight_shoot  25
mirp[min,rnd,grey]  vstem_curve   18
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  headstem    35
mirp[rp0,rnd,grey]  headdia 10
mirp[min,rnd,grey]  headstem    29
srp1    18
srp2    13
sloop   5
ip  22 21 2 15 28
iup[y]
""",

    #ho_nokhuk
    "uni0E2E": """
srp0    55
mirp[rp0,min,rnd,grey]  front_ling 1
alignrp 22
mirp[min,rnd,grey]  hstem   12
shp[rp2]    42
mirp[rp0,rnd,grey]  hwidth_13    32
mirp[min,rnd,grey]  hstem   14
mdrp[min,rnd,grey]  56
srp0    42
mirp[rp0,rnd,grey]  headstem_plus_hole    7
mirp[min,rnd,grey]  headstem    36
srp0    22
mirp[min,rnd,grey]  hstem   52
srp1    15
srp2    32
sloop   6
ip  47 17 27 30 28 29
iup[x]
SVTCA[y-axis]                       ;Set freedom and projection Vectors To Coordinate Axis
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   14
mirp[rp0,rnd,grey]  vheight_shoot 25
mirp[min,rnd,grey]  vstem_curve   49
mdrp[rp0,rnd,grey]  19
mdrp[min,rnd,grey]  45
mdrp[rp0,min,rnd,white]  4
mirp[min,rnd,grey]  headstem    39
mirp[rp0,rnd,grey]  headdia 10
mirp[min,rnd,grey]  headstem    33
srp1    25
srp2    19
sloop   8
ip  28 27 29 47 30 17 15 32
iup[y]
""",

    #sra_aa
    "uni0E32": """
srp0    16
mdrp[rp0,min,rnd,grey]  8
mirp[rp0,min,rnd,grey]  hwidth_9   15
mirp[min,rnd,grey]  hstem 1
mdrp[min,rnd,grey]  17
iup[x]
svtca[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
mirp[min,rnd,grey]  vstem   5
srp1    12
srp2    1
sloop   2
ip  2 15
iup[y]
""",

    #sra_a
    "uni0E40": """
srp0    25
mirp[rp0,min,rnd,grey]  front_001 2
mirp[min,rnd,grey]  hstem 4
shp[rp2]    22
mdrp[min,rnd,grey]  26
srp0    22
mirp[rp0,rnd,white] headstem_plus_hole 10
mirp[min,rnd,grey]  headstem 16
iup[x]
svtca[y-axis]
MDAP[rnd]   25
mirp[min,rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 13
mirp[rp0,rnd,grey]  headdia 7
mirp[min,rnd,grey]  headstem 19
iup[y]
""",

    #sra_ae
    #use sra_a reference: uni0E40

    #sra_o
    "uni0E42": """
""",

    #sra_i_moun
    "uni0E43": """
srp0    64
mirp[rp0,min,rnd,grey]  front_khai 3
mirp[min,rnd,grey]  hstem 31
mdrp[min,rnd,grey]  65
srp0    3
mdrp[rp0,min,rnd,grey]  40
mirp[rp0,min,rnd,white] headhole 46
mirp[min,rnd,grey]  headstem 37
srp0    3
mdrp[rp0,min,rnd,grey] 20
mirp[rp0,min,rnd,grey] hstem 52
mdrp[rp0,min,rnd,white] 58
mirp[rp0,min,rnd,grey] vstem_small 14
mdrp[rp0,min,rnd,white] 9
mirp[min,rnd,grey] hstem 26
iup[x]
svtca[y-axis]
MDAP[rnd]   64
mirp[min,rnd,grey]  vheight_o 23
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 34
mirp[min,rnd,grey]  headstem 49
srp0    23
mirp[min,rnd,grey]  vstem 12
mdrp[rp0,rnd,grey]  61
mdrp[rp0,rnd,grey]  55
mirp[min,rnd,grey]  vstem 17
srp1    23
srp2    34
sloop   8
ip  9 26 7 28 6 29 4 31
iup[y]
""",

    #sra_i_mlai
    "uni0E44": """
srp0    38
mirp[rp0,min,rnd,grey]  front_001 3
alignrp 16
mirp[min,rnd,grey]  hstem 17
mdrp[min,rnd,grey]  39
srp0    3
mdrp[rp0,min,rnd,grey]  26
mirp[rp0,min,rnd,white] headhole 32
mirp[min,rnd,grey]  headstem 23
srp0    3
mdrp[min,rnd,grey]  7
mdrp[min,rnd,grey] 10
srp1 10
srp2 3
sloop 3
ip 11 4 6
iup[x]
svtca[y-axis]
MDAP[rnd]   38
mirp[min,rnd,grey]  vheight_o 17
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 29
mirp[rp0,rnd,grey]  headdia 20
mirp[min,rnd,grey]  headstem 35
srp0    17
mirp[min,rnd,grey]  vstem 4
srp1    17
srp2    3
sloop   4
ip  11 10 4 7
iup[y]
""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
